# coding: utf-8

"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from freeradical_client.models.analytics_summary_get200_response import AnalyticsSummaryGet200Response

class TestAnalyticsSummaryGet200Response(unittest.TestCase):
    """AnalyticsSummaryGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalyticsSummaryGet200Response:
        """Test AnalyticsSummaryGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalyticsSummaryGet200Response`
        """
        model = AnalyticsSummaryGet200Response()
        if include_optional:
            return AnalyticsSummaryGet200Response(
                total_views = 56,
                unique_visitors = 56
            )
        else:
            return AnalyticsSummaryGet200Response(
        )
        """

    def testAnalyticsSummaryGet200Response(self):
        """Test AnalyticsSummaryGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
