# coding: utf-8

"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from freeradical_client.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_analytics_summary_get(self) -> None:
        """Test case for analytics_summary_get

        Get analytics summary
        """
        pass

    def test_auth_login_post(self) -> None:
        """Test case for auth_login_post

        Authenticate user
        """
        pass

    def test_pages_get(self) -> None:
        """Test case for pages_get

        List pages
        """
        pass

    def test_pages_post(self) -> None:
        """Test case for pages_post

        Create a page
        """
        pass

    def test_pages_uuid_get(self) -> None:
        """Test case for pages_uuid_get

        Get page by UUID
        """
        pass


if __name__ == '__main__':
    unittest.main()
