# coding: utf-8

"""
    FreeRadical CMS API

    Headless CMS API for FreeRadical

    The version of the OpenAPI document: 0.9.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from freeradical_client.models.login_response import LoginResponse

class TestLoginResponse(unittest.TestCase):
    """LoginResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LoginResponse:
        """Test LoginResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LoginResponse`
        """
        model = LoginResponse()
        if include_optional:
            return LoginResponse(
                token = '',
                user = freeradical_client.models.user.User(
                    id = 56, 
                    email = '', 
                    role = '', )
            )
        else:
            return LoginResponse(
        )
        """

    def testLoginResponse(self):
        """Test LoginResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
